define angular_separation()
%!%+
%\function{angular_separation}
%\usage{ sep=angular_separation(ra1,dec1,ra2,dec2);}
%\synopsis{calculates the angular distance between two points on a sphere}
%\qualifiers{
%\qualifier{deg}{: if set, the input coordinates and output are in degrees (default: radian)}
%\qualifier{radian}{: if set, the input coordinates and output are in radian (the default))}
%}
%\description
% This routine calculates the angular separation between points on the sky
% with coordinates ra1/dec1 and ra2/dec2.
%
% The function is equivalent to greatcircle_distance but is compatible in terms
% of its qualifiers with the other coordinate system routines. It also returns
% the angular separation in the units of the input parameters rather than
% always in rad.
%
% This function is array safe (for either ra1/dec1 or ra2/dec2).
%
%\seealso{hms2deg,dms2deg,angle2string,position_angle}
%!%-
{
    variable ra1in,dec1in,ra2in,dec2in;
    variable ra1,dec1,ra2,dec2;
    switch(_NARGS)
    { case 4: (ra1in,dec1in,ra2in,dec2in)=(); }
    { help(_function_name()); return; }

    if (qualifier_exists("deg")) {
	ra1=ra1in*PI/180.;
	dec1=dec1in*PI/180.;
	ra2=ra2in*PI/180.;
	dec2=dec2in*PI/180.;
    } else {
	ra1=@ra1in;
	dec1=@dec1in;
	ra2=@ra2in;
	dec2=@dec2in;
    }
    
    variable s,c,s1,c1,s2,c2;
    (s,c)=sincos(ra2-ra1);
    (s1,c1)=sincos(dec1);
    (s2,c2)=sincos(dec2);
    variable dist= atan2(sqrt((c2*s)^2 + (c1*s2 - s1*c2*c)^2), s1*s2 + c1*c2*c);

    if (qualifier_exists("deg")) {
	return dist*180./PI;
    }
    return dist;
}
